summaryrefslogtreecommitdiffstats
path: root/src/structs.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/structs.h')
-rw-r--r--src/structs.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/structs.h b/src/structs.h
index 6d77deb454..85f440d35d 100644
--- a/src/structs.h
+++ b/src/structs.h
@@ -4879,11 +4879,12 @@ typedef struct {
hashtab_T sve_hashtab;
} save_v_event_T;
// Enum used by filter(), map() and mapnew()
typedef enum {
FILTERMAP_FILTER,
FILTERMAP_MAP,
- FILTERMAP_MAPNEW
+ FILTERMAP_MAPNEW,
+ FILTERMAP_FOREACH
} filtermap_T;
// Structure used by switch_win() to pass values to restore_win()
@@ -4879,11 +4879,12 @@ typedef struct {
hashtab_T sve_hashtab;
} save_v_event_T;
-// Enum used by filter(), map() and mapnew()
+// Enum used by filter(), map(), mapnew() and foreach()
typedef enum {
FILTERMAP_FILTER,